platformdirs's documentation
============================

``platformdirs`` is a library to determine platform-specific system directories.
This includes directories where to place cache files, user data, configuration,
etc.

The source code and issue tracker are both hosted on `GitHub`_.

.. _GitHub: https://github.com/platformdirs/platformdirs

.. toctree::
   :maxdepth: 3

   api
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
